@@ -6,6 +6,7 @@
  */
 #include "waylandoutputmanagement.h"
 #include <QDebug>
+#include <QGuiApplication>
 
 namespace KScreen
 {
@@ -22,7 +23,7 @@ WaylandOutputManagement::WaylandOutputManagement(int version)
 
 WaylandOutputManagement::~WaylandOutputManagement()
 {
-    if (isActive()) {
+    if (qGuiApp && isActive()) {
         kde_output_management_v2_destroy(object());
     }
 }
@@ -62,33 +63,6 @@ void WaylandOutputConfiguration::kde_output_configuration_v2_failure_reason(cons
 {
     m_errorMessage = reason;
 }
-
-WaylandOutputOrder::WaylandOutputOrder(struct ::wl_registry *registry, int id, int version)
-    : QtWayland::kde_output_order_v1(registry, id, version)
-{
-}
-
-WaylandOutputOrder::~WaylandOutputOrder()
-{
-    destroy();
-}
-
-QList<QString> WaylandOutputOrder::order() const
-{
-    return m_outputOrder;
-}
-
-void WaylandOutputOrder::kde_output_order_v1_output(const QString &output_name)
-{
-    m_pendingOutputOrder.push_back(output_name);
-}
-
-void WaylandOutputOrder::kde_output_order_v1_done()
-{
-    m_outputOrder = m_pendingOutputOrder;
-    Q_EMIT outputOrderChanged(m_pendingOutputOrder);
-    m_pendingOutputOrder.clear();
-}
 }
 
 #include "moc_waylandoutputmanagement.cpp"
